<?php
if(!defined('VALID_CMS')) { die('ACCESS DENIED'); }
 
class cms_model_music{
    public $config = array();
    public $inDB;
 
    function __construct(){
        $this->inDB = cmsDatabase::getInstance();
        $this->config = self::getconfig();
    }
    
    /**
     * Возвращает конфигурацию по умолчанию
     * @return array
     */
    public static function getDefaultConfig(){
        return array(
            'music_perpage' => 10,
            'music_order_by' => 'm.pubdate',
            'music_order_to' => 'desc',
            'music_pagetitle' => 'Музыкальный альбом, список песен',
            'music_metadesc' => 'Музыкальный альбом, список песен',
            'music_metakeys' => 'Музыкальный альбом, список песен',
            
            'singers_perpage' => 10,
            'singers_pagetitle' => 'Музыкальный альбом, список исполнителей',
            'singers_metadesc' => 'Музыкальный альбом, список исполнителей',
            'singers_metakeys' => 'Музыкальный альбом, список исполнителей',
            
            'albums_perpage' => 10,
            'albums_pagetitle' => 'Музыкальный альбом, список альбомов',
            'albums_metadesc' => 'Музыкальный альбом, список альбомов',
            'albums_metakeys' => 'Музыкальный альбом, список альбомов',
            
            'one_player' => array(
                'pl' => '/components/music/uppod/uppod.swf',
                'st' => '/components/music/uppod/audioview.txt'
            ),
            'player' => array(
                'pl' => '/components/music/uppod/uppod.swf',
                'st' => '/components/music/uppod/audio58-1087.txt'
            )
        );
    }
    
    /**
     * Возвращает конфигурацию
     * @return array
     */
    public static function getconfig(){
        $inCore = cmsCore::getinstance();
        $cfg = array_merge(
            self::getDefaultConfig(),
            $inCore->loadComponentConfig('music')
        );
        return $cfg;
    }
    
    public function addMusic($name, $singer_id, $album_id, $genre_id, $user_id, $music_url){
        return $this->inDB->insert(
            'cms_music',
            array(
                'user_id' => $user_id,
                'name' => $this->inDB->escape_string($name),
                'album_id' => $album_id,
                'singer_id' => $singer_id,
                'genre_id' => $genre_id,
                'music_url' => $music_url,
                'pubdate' => date('Y-m-d H:i:s')
            )
        );
    }
	
    public function deleteMusic($music_id){
        $music = $this->getMus($music_id);

        unlink($music['music_del_url']);

        $this->inDB->query("DELETE FROM cms_music WHERE id = '". $music_id ."'");
        $this->inDB->query("DELETE FROM cms_music_pl WHERE music_id = '". $music_id ."'");

        return true;
    }
    
    public function getMus($music_id){
        $result = $this->inDB->query("
            SELECT m.*, a.album_name as album, s.singer_name as singer, g.genre_name as genre, pl.id as in_pl
                FROM cms_music m
                LEFT JOIN cms_music_album a ON a.id=m.album_id
                INNER JOIN cms_music_singer s ON s.id=m.singer_id
                LEFT JOIN cms_music_genre g ON g.id=m.genre_id
                LEFT JOIN cms_music_pl pl ON pl.music_id=m.id
                WHERE m.id='". $music_id ."' LIMIT 1");

        if (!$this->inDB->num_rows($result)) { return false; }

        $music = $this->inDB->fetch_assoc($result);
        
        $music['pubdate'] = cmsCore::dateFormat($music['pubdate']);
        $music['music_del_url'] = PATH . $music['music_url'];

        return $music;
    }

    public function getMusicTotal(){
        return $this->inDB->rows_count('cms_music m', "1=1 ". $this->inDB->where);
    }
    
    public function getMusic(){
        $results = $this->inDB->query("
            SELECT m.*, a.album_name as album, s.singer_name as singer, g.genre_name as genre, pl.id as in_pl
                FROM cms_music m
                LEFT JOIN cms_music_album a ON a.id=m.album_id
                INNER JOIN cms_music_singer s ON s.id=m.singer_id
                LEFT JOIN cms_music_genre g ON g.id=m.genre_id
                LEFT JOIN cms_music_pl pl ON pl.music_id=m.id
                WHERE 1=1 ". $this->inDB->where ." ". $this->inDB->order_by ." ". ($this->inDB->limit ? 'LIMIT '. $this->inDB->limit : ''));
        
        $this->inDB->resetConditions();
        
        if (!$this->inDB->num_rows($results)){ return false; }

        $items = array();
        while ($item = $this->inDB->fetch_assoc($results)){
            $item['pubdate'] = cmsCore::dateFormat($item['pubdate']);

            $item['music_del_url'] = PATH . $item['music_url'];
            
            $item['in_pl'] = empty($item['in_pl']) ? false : true;
            
            $items[] = $item;
        }

        return $items;
    }
	
    public function addmuspl($music_id, $user_id){
        if (!$this->inDB->get_field('cms_music_pl', "music_id='". $music_id ."'", 'id')){
            $this->inDB->insert('cms_music_pl', array('music_id' => $music_id, 'user_id' => $user_id));
        }else{
            return 1;
        }
        return 3;
    }
	
    public function delmuspl($music_id, $user_id){
        $this->inDB->query("DELETE FROM cms_music_pl WHERE music_id = '". $music_id ."' AND user_id = '". $user_id ."'");
        return true;
    }
	
    public function getCommentTarget($target, $target_id){
        $item = array();
        $item['link'] = '/music/musics'. $target_id;
        $item['title'] = $this->inDB->get_field('cms_music', "id='". $target_id ."'", 'name');
        return $item;
    }
	
    public function listen($music_id){
        $this->inDB->query("UPDATE cms_music SET listen=listen+1 WHERE id='". $music_id ."'");
    }
	
    public function listened($music_id){
        $this->inDB->query("UPDATE cms_music SET listened=listened+1 WHERE id='". $music_id ."'");
    }
    
    public function getAlbum($album_id){
        $item = $this->inDB->get_fields('cms_music_album', "id='". $album_id ."'", '*');
        if ($item){
            $item['pubdate'] = cmsCore::dateFormat($item['pubdate']);
        }
        return $item;
    }
    
    public function getSinger($singer_id){
        $item = $this->inDB->get_fields('cms_music_singer', "id='". $singer_id ."'", '*');
        if ($item){
            $item['pubdate'] = cmsCore::dateFormat($item['pubdate']);
        }
        return $item;
    }
    
    public function getAlbumId($name){
        $item_id = $this->inDB->get_field('cms_music_album', "album_name LIKE '%". $this->inDB->escape_string($name) ."%'", 'id');
        return empty($item_id) ? 0 : $item_id;
    }
    
    public function getSingerId($name){
        $item_id = $this->inDB->get_field('cms_music_singer', "singer_name LIKE '%". $this->inDB->escape_string($name) ."%'", 'id');
        return empty($item_id) ? 0 : $item_id;
    }
    
    public function addAlbum($album, $user_id){
        return $this->inDB->insert('cms_music_album', array('album_name' => $this->inDB->escape_string($album), 'user_id' => $user_id, 'pubdate' => date('Y-m-d H:i:s')));
    }
    
    public function addSinger($singer, $user_id){
        return $this->inDB->insert('cms_music_singer', array('singer_name' => $this->inDB->escape_string($singer), 'user_id' => $user_id, 'pubdate' => date('Y-m-d H:i:s')));
    }
    
    public function getSingersTotal(){
        return $this->inDB->rows_count('cms_music_singer', "1=1");
    }
    
    public function getSingers($page, $perpage){
        $results = $this->inDB->query("SELECT * FROM cms_music_singer WHERE 1=1 ORDER BY pubdate DESC LIMIT ". (($page-1)*$perpage) .", ". $perpage);
        
        if (!$this->inDB->num_rows($results)){ return false; }
        
        $items = array();
        while ($item = $this->inDB->fetch_assoc($results)){
            $item['pubdate'] = cmsCore::dateFormat($item['pubdate']);
            $item['mus'] = $this->inDB->rows_count('cms_music', "singer_id='". $item['id'] ."'");
            $items[] = $item;
        }
        return $items;
    }
    
    public function getAlbumsTotal(){
        return $this->inDB->rows_count('cms_music_singer', "1=1");
    }
    
    public function getAlbums($page, $perpage){
        $results = $this->inDB->query("SELECT * FROM cms_music_album WHERE 1=1 ORDER BY pubdate DESC LIMIT ". (($page-1)*$perpage) .", ". $perpage);
        
        if (!$this->inDB->num_rows($results)){ return false; }
        
        $items = array();
        while ($item = $this->inDB->fetch_assoc($results)){
            $item['pubdate'] = cmsCore::dateFormat($item['pubdate']);
            $item['mus'] = $this->inDB->rows_count('cms_music', "album_id='". $item['id'] ."'");
            $items[] = $item;
        }
        return $items;
    }
    
    public function getGenre(){
        $results = $this->inDB->query("SELECT * FROM cms_music_genre WHERE 1=1 ORDER BY genre_name ASC");
        
        if (!$this->inDB->num_rows($results)){ return false; }
        
        $items = array();
        while ($item = $this->inDB->fetch_assoc($results)){
            $items[] = $item;
        }
        return $items;
    }
    
    public function getMusName($id){
        return $this->inDB->get_field('cms_music', "id='". $id ."'", 'name');
    }
    
    public function getSingerName($id){
        return $this->inDB->get_field('cms_music_singer', "id='". $id ."'", 'singer_name');
    }
    
    public function getAlbumName($id){
        return $this->inDB->get_field('cms_music_album', "id='". $id ."'", 'album_name');
    }
    
    public function EditAlbum($album_id, $album_name, $description, $photo=false){
        $item = array();
        
        $item['album_name'] = $this->inDB->escape_string($album_name);
        $item['description'] = $this->inDB->escape_string($description);
        
        if (!empty($photo)){ $item['photo'] = $photo; }
        
        $this->inDB->update('cms_music_album', $item, $album_id);
        return true;
    }
    
    public function EditSinger($singer_id, $singer_name, $description, $photo=false){
        $item = array();
        
        $item['singer_name'] = $this->inDB->escape_string($singer_name);
        $item['description'] = $this->inDB->escape_string($description);
        
        if (!empty($photo)){ $item['photo'] = $photo; }
        
        $this->inDB->update('cms_music_singer', $item, $singer_id);
        return true;
    }
    
    public function getPl($user_id){
        return $this->inDB->get_field('cms_music_pl_list', "user_id='". $user_id ."'", 'id') ? true : false;
    }

    public function addPl($user_id){
        $this->inDB->insert('cms_music_pl_list', array('user_id' => $user_id, 'pl_name' => 'Избранное'));
        return true;
    }
    
    public function getMusPl($user_id){
        $results = $this->inDB->query("
                SELECT m.*, pl.music_id, a.album_name as album, s.singer_name as singer, g.genre_name as genre
                    FROM cms_music_pl pl
                    INNER JOIN cms_music m ON m.id=pl.music_id
                    LEFT JOIN cms_music_album a ON a.id=m.album_id
                    INNER JOIN cms_music_singer s ON s.id=m.singer_id
                    LEFT JOIN cms_music_genre g ON g.id=m.genre_id
                    WHERE pl.user_id='". $user_id ."' ORDER BY pl.id DESC");
        $this->inDB->resetConditions();
        
        if (!$this->inDB->num_rows($results)) { return false; }

        $items = array();
        while ($item = $this->inDB->fetch_assoc($results)){
            $item['pubdate'] = cmsCore::dateFormat($item['pubdate']);
            $items[] = $item;
        }
        
        return $items;
    }
    
    public function getMusPlmini($user_id){
        $results = $this->inDB->query("SELECT music_id FROM cms_music_pl WHERE user_id='". $user_id ."' ORDER BY id DESC");
        if (!$this->inDB->num_rows($results)){ return false; }

        $items = array();
        while ($item = $this->inDB->fetch_assoc($results)){
            $items[] = $item;
        }
        
        return $items;
    }
}
?>